@@ -1,7 +1,7 @@
 /* -------------------------------------------------------------
 
 This file is a component of SDPA
-Copyright (C) 2004-2010 SDPA Project
+Copyright (C) 2004-2011 SDPA Project
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -33,8 +33,7 @@ void IO::read(FILE* fpData, FILE* fpout, int& m, char* str)
 {
   while (true) {
     volatile int dummy=0; dummy++;//for gcc-3.3 bug
-    char* dummy2;
-    dummy2 =  fgets(str,lengthOfString,fpData);
+    fgets(str,lengthOfString,fpData);
     if (str[0]=='*' || str[0]=='"') {
       fprintf(fpout,"%s",str);
     } else {
@@ -46,15 +45,13 @@ void IO::read(FILE* fpData, FILE* fpout, int& m, char* str)
 
 void IO::read(FILE* fpData, int & nBlock)
 {
-  int dummy;
-  dummy = fscanf(fpData,"%d",&nBlock);
+  fscanf(fpData,"%d",&nBlock);
 }
 
 void IO::read(FILE* fpData, BlockStruct& bs)
 {
   for (int l=0; l<bs.nBlock; ++l) {
-    int dummy;
-    dummy = fscanf(fpData,"%*[^0-9+-]%d",&bs.blockStruct[l]);
+    fscanf(fpData,"%*[^0-9+-]%d",&bs.blockStruct[l]);
   }
   // only for SDP and LP
   for (int l=0; l<bs.nBlock; ++l) {
@@ -70,8 +67,7 @@ void IO::read(FILE* fpData, BlockStruct& bs)
 void IO::read(FILE* fpData, Vector& b)
 {
   for (int k=0; k<b.nDim; ++k) {
-    int dummy;
-    dummy = fscanf(fpData,"%*[^0-9+-]%lf",&b.ele[k]);
+    fscanf(fpData,"%*[^0-9+-]%lf",&b.ele[k]);
   }
 }
 
@@ -90,8 +86,7 @@ void IO::read(FILE* fpData, DenseLinearSpace& xMat,
     k++;
   }
   for (; k<yVec.nDim; ++k) {
-    int dummy; 
-    dummy = fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
+    fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
     yVec.ele[k] = -tmp;
     // rMessage("yVec.ele[" << k << "] = " << -tmp);
   }
@@ -167,8 +162,7 @@ void IO::read(FILE* fpData, DenseLinearSpace& xMat,
 	for (int i=0; i<size; ++i) {
 	  for (int j=0; j<size; ++j) {
 	    double tmp;
-	    int dummy;
-	    dummy = fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
+	    fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
 	    if (i<=j && tmp!=0.0) {
 	      zMat.setElement_SDP(l2,i,j,tmp);
 	    }
@@ -183,8 +177,7 @@ void IO::read(FILE* fpData, DenseLinearSpace& xMat,
 	int index = bs.blockNumber[l];
 	for (int j=0; j<size; ++j) {
 	  double tmp;
-	  int dummy;
-	  dummy = fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
+	  fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
 	  if (tmp!=0.0) {
 	    zMat.setElement_LP(index,tmp);
 	  }
@@ -200,8 +193,7 @@ void IO::read(FILE* fpData, DenseLinearSpace& xMat,
 	for (int i=0; i<size; ++i) {
 	  for (int j=0; j<size; ++j) {
 	    double tmp;
-	    int dummy;
-	    dummy = fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
+	    fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
 	    if (i<=j && tmp!=0.0) {
 	      xMat.setElement_SDP(l2,i,j,tmp);
 	    }
@@ -216,8 +208,7 @@ void IO::read(FILE* fpData, DenseLinearSpace& xMat,
 	int index = bs.blockNumber[l];
 	for (int j=0; j<size; ++j) {
 	  double tmp;
-	  int dummy; 
-	  dummy = fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
+	  fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
 	  if (tmp!=0.0) {
 	    xMat.setElement_LP(index,tmp);
 	  }
@@ -336,8 +327,7 @@ void IO::setBlockStruct(FILE* fpData, InputData& inputData, int m,
         for (int i=0; i<size; ++i) {
           for (int j=0; j<size; ++j) {
             double tmp;
-            int dummy;
-	    dummy = fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
+	    fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
             if (i<=j && tmp!=0.0) {
               SDP_index[0].push_back(l2);
             }
@@ -350,8 +340,7 @@ void IO::setBlockStruct(FILE* fpData, InputData& inputData, int m,
 	int size  = bs.blockStruct[l];
         for (int j=0; j<size; ++j) {
           double tmp;
-          int dummy;
-	  dummy = fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
+	  fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
           if (tmp!=0.0) {
               LP_index[0].push_back(start+j);
           }
@@ -369,8 +358,7 @@ void IO::setBlockStruct(FILE* fpData, InputData& inputData, int m,
           for (int i=0; i<size; ++i) {
             for (int j=0; j<size; ++j) {
               double tmp;
-              int dummy;
-	      dummy = fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
+	      fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
               if (i<=j && tmp!=0.0) {
                 SDP_index[k+1].push_back(l2);
               }
@@ -383,8 +371,7 @@ void IO::setBlockStruct(FILE* fpData, InputData& inputData, int m,
 	  int size  = bs.blockStruct[l];
           for (int j=0; j<size; ++j) {
             double tmp;
-            int dummy;
-	    dummy = fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
+	    fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
             if (tmp!=0.0) {
               LP_index[k+1].push_back(start+j);
             }
@@ -552,8 +539,7 @@ void IO::setElement(FILE* fpData, InputData& inputData, int m,
 	for (int i=0; i<size; ++i) {
 	  for (int j=0; j<size; ++j) {
 	    double tmp;
-	    int dummy;
-	    dummy = fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
+	    fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
 	    if (i<=j && tmp!=0.0) {
 	      inputData.C.setElement_SDP(l2,i,j,-tmp);
 	    }
@@ -566,8 +552,7 @@ void IO::setElement(FILE* fpData, InputData& inputData, int m,
 	int size  = bs.blockStruct[l];
 	for (int j=0; j<size; ++j) {
 	  double tmp;
-	  int dummy;
-	  dummy = fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
+	  fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
 	  if (tmp!=0.0) {
 	    inputData.C.setElement_LP(start+j,-tmp);
 	  }
@@ -587,8 +572,7 @@ void IO::setElement(FILE* fpData, InputData& inputData, int m,
 	  for (int i=0; i<size; ++i) {
 	    for (int j=0; j<size; ++j) {
 	      double tmp;
-	      int dummy;
-	      dummy = fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
+	      fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
 	      if (i<=j && tmp!=0.0) {
 		inputData.A[k].setElement_SDP(l2,i,j,tmp);
 	      }
@@ -601,8 +585,7 @@ void IO::setElement(FILE* fpData, InputData& inputData, int m,
 	  int size  = bs.blockStruct[l];
 	  for (int j=0; j<size; ++j) {
 	    double tmp;
-	    int dummy;
-	    dummy = fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
+	    fscanf(fpData,"%*[^0-9+-]%lf",&tmp);
 	    if (tmp!=0.0) {
 	      inputData.A[k].setElement_LP(start+j,tmp);
 	    }
