@@ -1,7 +1,7 @@
 /* -------------------------------------------------------------
 
 This file is a component of SDPA
-Copyright (C) 2004-2010 SDPA Project
+Copyright (C) 2004-2011 SDPA Project
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -49,11 +49,14 @@ double Lal::getMinEigen(DenseMatrix& lMat,
   beta = sqrt((double)nDim);  // norm of "r"
 
   // nakata 2004/12/12
-  while (k<nDim && k<sqrt((double)nDim)+10
+  while (k<nDim
+	 && k<sqrt((double)nDim)+10
 	 && beta > 1.0e-16
-	 && (fabs(min-min_old) > (1.0e-5)*fabs(min)+(1.0e-8)
+	 && ( k<20 ||
+	      fabs(min-min_old) > (1.0e-5)*fabs(min)+(1.0e-8)
 	     // && (fabs(min-min_old) > (1.0e-3)*fabs(min)+(1.0e-6)
-	     || fabs(error*beta) > (1.0e-2)*fabs(min)+(1.0e-4) )) {
+	      || fabs(error*beta) > (1.0e-2)*fabs(min)+(1.0e-6) )
+	 ) {
     // rMessage("k = " << k);
     qold.copyFrom(q);
     value = 1.0/beta;
