@@ -1,7 +1,7 @@
 /* -------------------------------------------------------------
 
 This file is a component of SDPA
-Copyright (C) 2004-2010 SDPA Project
+Copyright (C) 2004-2011 SDPA Project
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -1340,14 +1340,14 @@ void* Newton::compute_bMat_dense_SDP_thread_func(void *arg)
 {
   int l, m;
   int k1;
-  int SDP_nBlock;
   DenseMatrix work1, work2;
 
   thread_arg_t *targ = (thread_arg_t *)arg;
  
   l = targ->Block_Number;
   m = targ->mDIM;
-  SDP_nBlock = targ->SDP_nBlock;
+  // int SDP_nBlock;
+  // SDP_nBlock = targ->SDP_nBlock;
 
   //  printf("targ-> Block_Number = %d\n", targ-> Block_Number); 
 
@@ -1655,13 +1655,13 @@ void* Newton::compute_bMat_sparse_SDP_thread_func(void *arg)
 {
   int l;
   int iter;
-  int SDP_nBlock;
   DenseMatrix work1, work2;
   int previous_j = -1;
   thread_arg_t *targ = (thread_arg_t *)arg;
  
   l          = targ->Block_Number;
-  SDP_nBlock = targ->SDP_nBlock;
+  // int SDP_nBlock;
+  // SDP_nBlock = targ->SDP_nBlock;
 
   //  printf("targ-> Block_Number = %d\n", targ-> Block_Number); 
 
