@@ -1,7 +1,7 @@
 /* -------------------------------------------------------------
 
 This file is a component of SDPA
-Copyright (C) 2004-2010 SDPA Project
+Copyright (C) 2004-2011 SDPA Project
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -230,21 +230,20 @@ char Parameter::infPRINT_DEFAULT[PRINT_DEFAULT_LENGTH] = "%+10.16e";
 
 void Parameter::readFile(FILE* parameterFile)
 {
-  int dummy;
-  dummy = fscanf(parameterFile,"%d%*[^\n]",&maxIteration);
-  dummy = fscanf(parameterFile,"%lf%*[^\n]",&epsilonStar);
-  dummy = fscanf(parameterFile,"%lf%*[^\n]",&lambdaStar);
-  dummy = fscanf(parameterFile,"%lf%*[^\n]",&omegaStar);
-  dummy = fscanf(parameterFile,"%lf%*[^\n]",&lowerBound);
-  dummy = fscanf(parameterFile,"%lf%*[^\n]",&upperBound);
-  dummy = fscanf(parameterFile,"%lf%*[^\n]",&betaStar);
-  dummy = fscanf(parameterFile,"%lf%*[^\n]",&betaBar);
-  dummy = fscanf(parameterFile,"%lf%*[^\n]",&gammaStar);
-  dummy = fscanf(parameterFile,"%lf%*[^\n]",&epsilonDash);
-  dummy = fscanf(parameterFile,"%s %*[^\n]",xPrint);
-  dummy = fscanf(parameterFile,"%s %*[^\n]",XPrint);
-  dummy = fscanf(parameterFile,"%s %*[^\n]",YPrint);
-  dummy = fscanf(parameterFile,"%s %*[^\n]",infPrint);
+  fscanf(parameterFile,"%d%*[^\n]",&maxIteration);
+  fscanf(parameterFile,"%lf%*[^\n]",&epsilonStar);
+  fscanf(parameterFile,"%lf%*[^\n]",&lambdaStar);
+  fscanf(parameterFile,"%lf%*[^\n]",&omegaStar);
+  fscanf(parameterFile,"%lf%*[^\n]",&lowerBound);
+  fscanf(parameterFile,"%lf%*[^\n]",&upperBound);
+  fscanf(parameterFile,"%lf%*[^\n]",&betaStar);
+  fscanf(parameterFile,"%lf%*[^\n]",&betaBar);
+  fscanf(parameterFile,"%lf%*[^\n]",&gammaStar);
+  fscanf(parameterFile,"%lf%*[^\n]",&epsilonDash);
+  fscanf(parameterFile,"%s %*[^\n]",xPrint);
+  fscanf(parameterFile,"%s %*[^\n]",XPrint);
+  fscanf(parameterFile,"%s %*[^\n]",YPrint);
+  fscanf(parameterFile,"%s %*[^\n]",infPrint);
   if (strcmp(xPrint,NO_P_FORMAT)!=0 && xPrint[0]!='%') {
     rMessage("Strange xPrint[" << xPrint << "]"
 	     " migh cause trouble when printing x");
