@@ -1,7 +1,7 @@
 /* -------------------------------------------------------------
 
 This file is a component of SDPA
-Copyright (C) 2004-2010 SDPA Project
+Copyright (C) 2004-2011 SDPA Project
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -34,6 +34,12 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 ------------------------------------------*/
   
 static const char sdpa_right[] =
-  "SDPA7 (2008Feb/Margaret) has been developed by SDPA Project.";
+  "SDPA7 (Margaret/since 2008Feb) has been developed by SDPA Project.";
+#ifdef VERSION
+// VERSION is set by configure script
+static const char sdpa_version[] = VERSION;
+#else
+// static const char sdpa_version[] = "7";
+#endif
 
 #endif // __sdpa_right_h__
